/*******************************************************************************
  Main Source File

  Company:
    Microchip Technology Inc.

  File Name:
    main.c

  Summary:
    This file contains the "main" function for a project.

  Description:
    This file contains the "main" function for a project.  The
    "main" function calls the "SYS_Initialize" function to initialize the state
    machines of all modules in the system
 *******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************

#include <stddef.h>                     // Defines NULL
#include <stdbool.h>                    // Defines true
#include <stdlib.h>                     // Defines EXIT_FAILURE
#include "definitions.h"                // SYS function prototypes


// *****************************************************************************
// *****************************************************************************
// Section: Main Entry Point
// *****************************************************************************
// *****************************************************************************

// CAN BUS struktura:
typedef struct {
    uint32_t ID;                                                                // CAN filter ID.
    uint8_t length;                                                             // Kolicina podataka.
    uint8_t data[8];                                                            // Niz podataka koji se salju (maksimalno 8 bajtova za CAN).
    CAN_MSG_RX_ATTRIBUTE msgAttr;                                               // Vrsta poruke.
}can_t;

int main ( void )
{
    uint8_t r;                                                                  
    can_t buffer;
    /* Initialize all modules */
    buffer.ID = 0x1B00;                                                         // Filter ID prijemnika.
    buffer.length = 1;                                                          // Duzina poruke koja se salje putem CAN busa - jedan karakter (tj. jedan bajt).
    buffer.msgAttr = CAN_MSG_TX_DATA_FRAME;                                     // Frame koji sadrzi podatke za slanje na drugi uredjaj.
   
    
    SYS_Initialize ( NULL ); 
    CORETIMER_DelayMs(1000);
    
    while ( true )
    {
        
         if(UART1_ReceiverIsReady())                                            // Ukoliko je podatak dostupan na UART-u:
        {
            r = UART1_ReadByte();                                               // Citanje jednog bajta podataka sa UART-a.
            buffer.data[0] = r;                                                 // Podatak ocitan sa UART-a bice poslat preko CAN bus-a. 
            CAN1_MessageTransmit(buffer.ID, buffer.length, buffer.data, 0, buffer.msgAttr);             // Slanje podatka putem CAN bus-a.
        }
        CORETIMER_DelayMs(1000);
    }

    /* Execution should not come here during normal operation */

    return ( EXIT_FAILURE );
}


/*******************************************************************************
 End of File
*/

