/*******************************************************************************
  Main Source File

  Company:
    Microchip Technology Inc.

  File Name:
    main.c

  Summary:
    This file contains the "main" function for a project.

  Description:
    This file contains the "main" function for a project.  The
    "main" function calls the "SYS_Initialize" function to initialize the state
    machines of all modules in the system
 *******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************

#include <stddef.h>                     // Defines NULL
#include <stdbool.h>                    // Defines true
#include <stdlib.h>                     // Defines EXIT_FAILURE
#include "definitions.h"                // SYS function prototypes


// *****************************************************************************
// *****************************************************************************
// Section: Main Entry Point
// *****************************************************************************
// *****************************************************************************

// CAN BUS struktura:
typedef struct {
    uint32_t ID;
    uint8_t length;
    uint8_t data[8];
    CAN_MSG_RX_ATTRIBUTE msgAttr;
} can_t;

int main ( void )
{
    can_t buffer;
    /* Initialize all modules */
    SYS_Initialize ( NULL );
    
    
    while ( true )
    {
        while(!CAN1_MessageReceive(&buffer.ID, &buffer.length, buffer.data, NULL, 1, &buffer.msgAttr));       // Kod je blokiran u ovoj liniji dok ne pristignu podaci preko CAN bus-a.
        
        GPIO_PortClear(GPIO_PORT_A, 0xFFFF);                                    // Postavljanje stanja na svim pinovima porta A od RA0 do RA15 na 0. 
        GPIO_PortClear(GPIO_PORT_B, 0xFFFF);                                    // Postavljanje stanja na svim pinovima porta B od RB0 do RB15 na 0.
        
        printf("%x\r\n", buffer.data[0]);                                       // Ispis podatka koji je pristigao preko CAN bus-a u terminalu.
        
        switch(buffer.data[0]){                                                 // U odnosu na karakter koji je primljen na CAN bus-u.
            case 'A':                                                           // U slucaju da je pristigli karakter slovo 'A':
                GPIO_PortSet(GPIO_PORT_A, 0xFFFF);                              // Ukljucuju se sve diode porta A (pinovi RA0:RA15).
                break;
            case 'B':                                                           // U slucaju da je pristigli karakter slovo 'B':
                GPIO_PortSet(GPIO_PORT_B, 0xFFFF);                              // Ukljucuju se sve diode porta B (pinovi RB0:RB15).
                break;
            default:
                printf("Addr 0x%x\r\n",buffer.ID);                              // U slucaju da pristigli karakter nije ni 'A' ni 'B' ispisuje se filter ID.
                break;
        }
    }

    /* Execution should not come here during normal operation */
    
    return ( EXIT_FAILURE );
}


/*******************************************************************************
 End of File
*/

