/*******************************************************************************
  Main Source File

  Company:
    Microchip Technology Inc.

  File Name:
    main.c

  Summary:
    This file contains the "main" function for a project.

  Description:
    This file contains the "main" function for a project.  The
    "main" function calls the "SYS_Initialize" function to initialize the state
    machines of all modules in the system
 *******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************

#include <stddef.h>                     // Defines NULL
#include <stdbool.h>                    // Defines true
#include <stdlib.h>                     // Defines EXIT_FAILURE
#include "definitions.h"                // SYS function prototypes
#include <stdint.h>

// *****************************************************************************
// *****************************************************************************
// Section: Main Entry Point
// *****************************************************************************
// *****************************************************************************
typedef struct {
    uint32_t ID;
    uint8_t length;
    uint8_t data[1];
    CAN_MSG_RX_ATTRIBUTE msgAttr;
} can_t;

volatile bool flag1=false;
volatile bool flag2=false;
volatile bool flag3=false;
volatile bool flag4=false;

void GPIO_RD0_IntHandle(GPIO_PIN pin, uintptr_t context)
{
    flag1 = true;                                                               // U slucaju da je generisan interrupt sa pina RD0 flag1 dobija vrednost true.                                                                
}

void GPIO_RD1_IntHandle(GPIO_PIN pin, uintptr_t context)
{
    flag2 = true;                                                               // U slucaju da je generisan interrupt sa pina RD1 flag2 dobija vrednost true.
}

void GPIO_RD2_IntHandle(GPIO_PIN pin, uintptr_t context)
{
    flag3 = true;                                                               // U slucaju da je generisan interrupt sa pina RD2 flag3 dobija vrednost true.
}

void GPIO_RD3_IntHandle(GPIO_PIN pin, uintptr_t context)
{
    flag4 = true;                                                               // U slucaju da je generisan interrupt sa pina RD3 flag4 dobija vrednost true.
}

int main ( void )
{
    can_t buffer;
    buffer.ID = 0x1B00;                                                         // Filter ID prijemnika.
    buffer.length = 1;                                                          // Jedan bajt podataka za slanje.
    buffer.msgAttr = CAN_MSG_TX_DATA_FRAME;                                     // Frame koji sadrzi podatke za slanje putem CAN bus-a.
    /* Initialize all modules */
    SYS_Initialize ( NULL );
    
    
    GPIO_PinInterruptCallbackRegister(GPIO_PIN_RD0, GPIO_RD0_IntHandle, (uintptr_t)NULL);       // Funkcija koja registruje da se funkcija GPIO_RD0_IntHandle izvrsava kada se dogodi interrupt na pinu RD0.
    GPIO_PinIntEnable(GPIO_PIN_RD0, GPIO_INTERRUPT_ON_MISMATCH);                                // Funkcija koja omogucava generisanje spoljasnjih interrupt-a na pinu RD0.
    
    GPIO_PinInterruptCallbackRegister(GPIO_PIN_RD1, GPIO_RD1_IntHandle, (uintptr_t)NULL);
    GPIO_PinIntEnable(GPIO_PIN_RD1, GPIO_INTERRUPT_ON_MISMATCH);
    
    GPIO_PinInterruptCallbackRegister(GPIO_PIN_RD2, GPIO_RD2_IntHandle, (uintptr_t)NULL);
    GPIO_PinIntEnable(GPIO_PIN_RD2, GPIO_INTERRUPT_ON_MISMATCH);
    
    GPIO_PinInterruptCallbackRegister(GPIO_PIN_RD3, GPIO_RD3_IntHandle, (uintptr_t)NULL);
    GPIO_PinIntEnable(GPIO_PIN_RD3, GPIO_INTERRUPT_ON_MISMATCH);
    
    CORETIMER_DelayMs(1000);
    
    while ( true )
    {
        if(flag1){                                                              // Ukoliko je pritisnut taster pina RD0:
            flag1=false;                                                        // Resetovanje flag1.
            buffer.data[0]=0;                                                   // Vrednost koja se salje CAN bus-om je 0.
        }
        else if(flag2){                                                         // Ukoliko je pritisnut taster pina RD1:
            flag2=false;                                                        // Resetovanje flag2.
            buffer.data[0]=1;                                                   // Vrednost koja se salje CAN bus-om je 1.
        }
        else if(flag3){                                                         // Ukoliko je pritisnut taster pina RD2:
            flag3=false;                                                        // Resetovanje flag3.
            buffer.data[0]=2;                                                   // Vrednost koja se salje CAN bus-om je 2.
        }
        else if(flag4){                                                         // Ukoliko je pritisnut taster pina RD3:
            flag4=false;                                                        // Resetovanje flag4.
            buffer.data[0]=3;                                                   // Vrednost koja se salje CAN bus-om je 3.
        }
        
        CAN1_MessageTransmit(buffer.ID, buffer.length, buffer.data, 0, buffer.msgAttr);         // Slanje poruke CAN bus-om na prijemnik.
        CORETIMER_DelayMs(1000);
    }

    /* Execution should not come here during normal operation */

    return ( EXIT_FAILURE );
}


/*******************************************************************************
 End of File
*/

