/*******************************************************************************
  Main Source File

  Company:
    Microchip Technology Inc.

  File Name:
    main.c

  Summary:
    This file contains the "main" function for a project.

  Description:
    This file contains the "main" function for a project.  The
    "main" function calls the "SYS_Initialize" function to initialize the state
    machines of all modules in the system
 *******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************

#include <stddef.h>                     // Defines NULL
#include <stdbool.h>                    // Defines true
#include <stdlib.h>                     // Defines EXIT_FAILURE
#include "definitions.h"                // SYS function prototypes


// *****************************************************************************
// *****************************************************************************
// Section: Main Entry Point
// *****************************************************************************
// *****************************************************************************
typedef struct {
    uint32_t ID;
    uint8_t length;
    uint8_t data[8];
    CAN_MSG_RX_ATTRIBUTE msgAttr;
} can_t;


int main ( void )
{
    
    can_t buffer;
    /* Initialize all modules */
    SYS_Initialize ( NULL );

    while ( true )
    {
        if(CAN1_MessageReceive(&buffer.ID, &buffer.length, buffer.data, NULL, 1, &buffer.msgAttr)){         // Ukoliko je poruka primljena putem CAN bus-a:
            GPIO_PortClear(GPIO_PORT_D, 0xF);                                   // Vrednosti na pinovima porta D - RD0, RD1, RD2 i RD3 se postavljaju na 0.
            switch(buffer.data[0]){                                             // U odnosu na sadrzaj pristigle poruke:
                case 0:
                    GPIO_RD0_Toggle();                                          // Ukljucuje se dioda koja odgovara pinu RD0.
                    CORETIMER_DelayMs(1000);
                    break;
                case 1:
                    GPIO_RD1_Toggle();                                          // Ukljucuje se dioda koja odgovara pinu RD1.
                    CORETIMER_DelayMs(1000);
                    break;
                case 2:
                    GPIO_RD2_Toggle();                                          // Ukljucuje se dioda koja odgovara pinu RD2.
                    CORETIMER_DelayMs(1000);
                    break;
                case 3:
                    GPIO_RD3_Toggle();                                          // Ukljucuje se dioda koja odgovara pinu RD3.
                    CORETIMER_DelayMs(1000);
                    break;
                default:
                    GPIO_PortClear(GPIO_PORT_D, 0xF);                           // U slucaju da pristigli podatak nije 1, 2, 3 ili 4, vrednosti na pinovima RD0, RD1, RD2 i RD3 se postavljaju na 0.
                    break;
            }
        }
    }

    /* Execution should not come here during normal operation */

    return ( EXIT_FAILURE );
}


/*******************************************************************************
 End of File
*/

